Class: Integral::ResourceAlternate
- Inherits:
-
ApplicationRecord
- Object
- ActiveRecord::Base
- ApplicationRecord
- Integral::ResourceAlternate
- Defined in:
- app/models/integral/resource_alternate.rb
Overview
Represents an alternate resource association, i.e. a page can have an alternate page which has the same content but in a different language